==> zio-aws-paymentcryptography_2.12-7.21.15.12-sources.jar: zio/aws/paymentcryptography/model/package.scala <==
package zio.aws.paymentcryptography
import zio.aws.paymentcryptography.model.primitives.TagKey
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.paymentcryptography.model.primitives.ExportTokenId.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AliasName extends Subtype[String]
    type AliasName = zio.aws.paymentcryptography.model.primitives.AliasName.Type
    object CertificateType extends Subtype[String]
    type CertificateType =
      zio.aws.paymentcryptography.model.primitives.CertificateType.Type
    object DeleteKeyInputDeleteKeyInDaysInteger extends Subtype[Int]
    type DeleteKeyInputDeleteKeyInDaysInteger =
      zio.aws.paymentcryptography.model.primitives.DeleteKeyInputDeleteKeyInDaysInteger.Type
    object ExportTokenId extends Subtype[String]
    type ExportTokenId =
      zio.aws.paymentcryptography.model.primitives.ExportTokenId.Type
    object HexLength16 extends Subtype[String]
    type HexLength16 =
      zio.aws.paymentcryptography.model.primitives.HexLength16.Type
    object ImportTokenId extends Subtype[String]
    type ImportTokenId =
      zio.aws.paymentcryptography.model.primitives.ImportTokenId.Type
    object KeyArn extends Subtype[String]
    type KeyArn = zio.aws.paymentcryptography.model.primitives.KeyArn.Type
    object KeyArnOrKeyAliasType extends Subtype[String]
    type KeyArnOrKeyAliasType =
      zio.aws.paymentcryptography.model.primitives.KeyArnOrKeyAliasType.Type
    object KeyCheckValue extends Subtype[String]
    type KeyCheckValue =
      zio.aws.paymentcryptography.model.primitives.KeyCheckValue.Type
    object KeyMaterial extends Subtype[String]
    type KeyMaterial =
      zio.aws.paymentcryptography.model.primitives.KeyMaterial.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.paymentcryptography.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.paymentcryptography.model.primitives.NextToken.Type
    object PrimitiveBoolean extends Subtype[Boolean]
    type PrimitiveBoolean =
      zio.aws.paymentcryptography.model.primitives.PrimitiveBoolean.Type
    object ResourceArn extends Subtype[String]
    type ResourceArn =
      zio.aws.paymentcryptography.model.primitives.ResourceArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.paymentcryptography.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.paymentcryptography.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.paymentcryptography.model.primitives.Timestamp.Type
    object Tr31WrappedKeyBlock extends Subtype[String]
    type Tr31WrappedKeyBlock =
      zio.aws.paymentcryptography.model.primitives.Tr31WrappedKeyBlock.Type
    object Tr34WrappedKeyBlock extends Subtype[String]
    type Tr34WrappedKeyBlock =
      zio.aws.paymentcryptography.model.primitives.Tr34WrappedKeyBlock.Type
  }
  type Aliases = List[zio.aws.paymentcryptography.model.Alias]
  type KeySummaryList = List[zio.aws.paymentcryptography.model.KeySummary]
  type TagKeys = List[TagKey]
  type Tags = List[zio.aws.paymentcryptography.model.Tag]
}

==> zio-aws-paymentcryptography_3-7.21.15.7-sources.jar: zio/aws/paymentcryptography/model/package.scala <==
package zio.aws.paymentcryptography
import zio.aws.paymentcryptography.model.primitives.TagKey
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.paymentcryptography.model.primitives.ExportTokenId.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AliasName extends Subtype[String]
    type AliasName = zio.aws.paymentcryptography.model.primitives.AliasName.Type
    object CertificateType extends Subtype[String]
    type CertificateType =
      zio.aws.paymentcryptography.model.primitives.CertificateType.Type
    object DeleteKeyInputDeleteKeyInDaysInteger extends Subtype[Int]
    type DeleteKeyInputDeleteKeyInDaysInteger =
      zio.aws.paymentcryptography.model.primitives.DeleteKeyInputDeleteKeyInDaysInteger.Type
    object ExportTokenId extends Subtype[String]
    type ExportTokenId =
      zio.aws.paymentcryptography.model.primitives.ExportTokenId.Type
    object HexLength16 extends Subtype[String]
    type HexLength16 =
      zio.aws.paymentcryptography.model.primitives.HexLength16.Type
    object ImportTokenId extends Subtype[String]
    type ImportTokenId =
      zio.aws.paymentcryptography.model.primitives.ImportTokenId.Type
    object KeyArn extends Subtype[String]
    type KeyArn = zio.aws.paymentcryptography.model.primitives.KeyArn.Type
    object KeyArnOrKeyAliasType extends Subtype[String]
    type KeyArnOrKeyAliasType =
      zio.aws.paymentcryptography.model.primitives.KeyArnOrKeyAliasType.Type
    object KeyCheckValue extends Subtype[String]
    type KeyCheckValue =
      zio.aws.paymentcryptography.model.primitives.KeyCheckValue.Type
    object KeyMaterial extends Subtype[String]
    type KeyMaterial =
      zio.aws.paymentcryptography.model.primitives.KeyMaterial.Type
    object MaxResults extends Subtype[Int]
    type MaxResults =
      zio.aws.paymentcryptography.model.primitives.MaxResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.paymentcryptography.model.primitives.NextToken.Type
    object PrimitiveBoolean extends Subtype[Boolean]
    type PrimitiveBoolean =
      zio.aws.paymentcryptography.model.primitives.PrimitiveBoolean.Type
    object ResourceArn extends Subtype[String]
    type ResourceArn =
      zio.aws.paymentcryptography.model.primitives.ResourceArn.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.paymentcryptography.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.paymentcryptography.model.primitives.TagValue.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.paymentcryptography.model.primitives.Timestamp.Type
    object Tr31WrappedKeyBlock extends Subtype[String]
    type Tr31WrappedKeyBlock =
      zio.aws.paymentcryptography.model.primitives.Tr31WrappedKeyBlock.Type
    object Tr34WrappedKeyBlock extends Subtype[String]
    type Tr34WrappedKeyBlock =
      zio.aws.paymentcryptography.model.primitives.Tr34WrappedKeyBlock.Type
  }
  type Aliases = List[zio.aws.paymentcryptography.model.Alias]
  type KeySummaryList = List[zio.aws.paymentcryptography.model.KeySummary]
  type TagKeys = List[TagKey]
  type Tags = List[zio.aws.paymentcryptography.model.Tag]
}
